Learn R Programming

RankAggSIgFUR (version 1.0.0)

get_indices: Determine Indices of Ranked Objects

Description

Used in Subiterative Convergence to determine the index of the subset of objects from the output from Modified Kemeny. These indices are then used to find the object indices for the next step in Subiterative Convergence.

Usage

get_indices(x, y)

Value

The index or indices of the ranked objects.

Arguments

x

a vector of integers, typically a series from 1 to \(\eta\) from Subiterative Convergence.

y

a vector containing the ranking, typically the output from Modified Kemeny.

See Also

subit_convergence