This function creates the new rankings for Greedy Algorithm after moving an object to a higher and lower rank within the search radius. Cyclical moving is permitted in the event of overflow.
get_sub_rkgs(seed_rkg, move_ind, search_radius)A matrix of the subset of rankings, with each row as a new ranking with the moved object.
a vector containing the initial ranking on which subsequent moves will be based.
an integer representing the index of the object to be moved.
a positive integer of the maximum shift allowed to increase or decrease the rank of the object.
rap_greedy_alg