Calculates the sum, maximum, and variance of k individual Kemeny distances of
multiple given rankings from input rankings.
totalKem_mult(rkgs, input_rkgs, pairs, wt = wt)A vector of the total Kemeny distance, the maximum Kemeny distance of the individual Kemeny distances, and the variance of the individual Kemeny distances.
a matrix of rankings to be compared against the input rankings. Each row must be a complete ranking, meaning that all of the objects have a rank.
a k by n matrix of k rankings of n
objects, where each row is a complete ranking. Note that this is a transpose of
matrix used for functions like fur, sigfur, rap_greedy_alg,
and subit_convergence.
a 2 by n choose 2 matrix of all combinations of
object pairs of n objects, where each column contains a pair of object indices.
a k-length vector containing weights for each
judge or attribute. An optional parameter.
mod_kemeny, subit_convergence, rap_greedy_alg,
seed_based_iteration