Learn R Programming

RankAggSIgFUR (version 1.0.0)

data240x4: PrefLib 240 \(\times\) 4 Data

Description

Data of 240 cities across the globe ranked on four criteria from the ED-00015-001.soc dataset in the PrefLib repository. The first column contains the object names and each subsequent column is a complete ranking of the 240 objects with no ties) .

Usage

data(data240x4)

Arguments

Format

A data frame with 240 rows and 5 columns:

Object

object name

Ranking 1

ranking on the first criterion

Ranking 2

ranking on the second criterion

Ranking 3

ranking on the third criterion

Ranking 4

ranking on the fourth criterion

References

Badal, P. S., & Das, A. (2018). Efficient algorithms using subiterative convergence for Kemeny ranking problem. Computers & Operations Research, 98, 198-210. tools:::Rd_expr_doi("10.1016/j.cor.2018.06.007")

Mattei, N., & Walsh, T. (2013, November). Preflib: A library for preferences https://www.preflib.org/. In International conference on algorithmic decision theory (pp. 259-270). Springer, Berlin, Heidelberg.

Examples

Run this code
data(data240x4)
input_rkgs <- t(as.matrix(data240x4[, -1]))
obj_names <- data240x4[,1]

# Determine the mean seed ranking
mean_seed(input_rkgs)

Run the code above in your browser using DataLab