Learn R Programming

RankAggSIgFUR (version 1.0.0)

data50x15: Simulated 50 \(\times\) 15 Data

Description

Data of 50 objects and 15 attributes, which were randomly generated from the 100 \(\times\) 15 simulated dataset (see data100x15). The first column contains the object names and each subsequent column is a complete ranking of the 50 objects.

Usage

data(data50x15)

Arguments

Format

A data frame with 50 rows and 16 columns:

Object

object name

Ranking 1

ranking on the first attribute

Ranking 2

ranking on the second attribute

Ranking 3

ranking on the third attribute

Ranking 4

ranking on the fourth attribute

Ranking 5

ranking on the fifth attribute

Ranking 6

ranking on the sixth attribute

Ranking 7

ranking on the seventh attribute

Ranking 8

ranking on the eigth attribute

Ranking 9

ranking on the ninth attribute

Ranking 10

ranking on the tenth attribute

Ranking 11

ranking on the eleventh attribute

Ranking 12

ranking on the twelfth attribute

Ranking 13

ranking on the thirteenth attribute

Ranking 14

ranking on the fourteenth attribute

Ranking 15

ranking on the fifteenth attribute

Examples

Run this code
data(data50x15)
input_rkgs <- t(as.matrix(data50x15[, -1]))
obj_names <- data50x15[,1]

# Determine the mean seed ranking
mean_seed(input_rkgs)

Run the code above in your browser using DataLab